/*
PhysicalComputingDemonstrations.h - Physical Computing for Lectures library
Created by Miguel Angel Rubio - marubio@ugr.es
date: June 2014

Copyright (C) 2014  Miguel Angel Rubio

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or any 
later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see http://www.gnu.org/licenses/ .

    Feel free to mail me if bugs or new ideas!
*/



#ifndef PHYSICAL_COMPUTING_DEMONSTRATIONS_H_
#define PHYSICAL_COMPUTING_DEMONSTRATIONS_H_

#include <Arduino.h>
//Limitations of Arduino IDE...
#include "../Servo/Servo.h" 

/////////////////////////////////////
//Leer Voltaje
//////////////////////////////////////

int lee_voltaje(int num_pin)
{
    int valor;
    valor = analogRead(num_pin);

    return valor;
}

/////////////////////////////////////
//Apagar LEDs
//////////////////////////////////////

//Sirve para apagar un nico LED

void apaga_led(int num_led)
{
    pinMode(num_led, OUTPUT);
    digitalWrite(num_led, LOW);
}

//Sirve para apagar multiples LEDs

void apaga_led(int num_led[], int size_led)
{
    for (int cont = 0; cont < size_led; cont++){
        pinMode(num_led[cont], OUTPUT);
        digitalWrite(num_led[cont], LOW);
        }
}

/////////////////////////////////////
//Encender LEDs
//////////////////////////////////////
//Sirve para encender un nico LED

void enciende_led(int num_led)
{
    pinMode(num_led, OUTPUT);
    digitalWrite(num_led, HIGH);
}

//Sirve para encender multiples LEDs

void enciende_led(int num_led[], int size_led)
{
    for (int cont = 0; cont < size_led; cont++){
        pinMode(num_led[cont], OUTPUT);
        digitalWrite(num_led[cont], HIGH);
        }
}


/////////////////////////////////////
//Mover Servo
//////////////////////////////////////
//Mueve el servo a una cierta posicin
//Se presupone que el servo est ya conectado

void mover_servo(Servo mi_servo, int posicion)
{
    mi_servo.write(posicion);   
}

/////////////////////////////////////
//Pausar unos segundos
//////////////////////////////////////

void para (float segundos)
{
    delay(segundos*1000);
}

/////////////////////////////////
//Leer temperatura
///////////////////////////////////
//Funcion lee_temp. Lee la temperatura mediante Arduino
//El sensor es el TMP36 del Arduino Starter Kit
//Entrada analog_pin: El pin que vamos a usar para leer la temperatura
//Salida: la temperatura
int lee_temperatura(int analog_pin){
 
 char str[256];

 //Realizamos 20 medidas para minimizar el error.
 float temp = 0;
 int num_medidas = 20;
 float voltaje;
 
 for (int cont = 0; cont < 20; cont++) {
    voltaje = lee_voltaje(analog_pin); //Medida directa
    voltaje = voltaje*5/1024; //Voltaje normalizado
    temp= temp+voltaje/0.01 - 50; //En C
 }

 //Hacemos la media y lo mostramos
 int temperatura = temp/num_medidas;
 return temperatura;
 
}

/////////////////////////////////
//Leer luminosidad
///////////////////////////////////
//Funcion luminosidad. Ve la luminosidad de la habitacion
//El sensor es el LDR-VT90N2 
//Ver los pdf adjuntos
//Entrada analog_pin: El pin que vamos a usar para leer la temperatura
//Argumento de salida
//El valor de luminosidad normalizado de 0 a 1
float lee_luminosidad (int analog_pin){
  float voltaje = lee_voltaje(analog_pin);
  voltaje = voltaje/1024.;
  return voltaje;
}

#endif // PHYSICAL_COMPUTING_DEMONSTRATIONS_H_